@@ -32,21 +32,20 @@ def mock_overcloud():
     return overcloud
 
 
-class RacksShellTest(tutils.TestCase):
+class OvercloudRoleShellTest(tutils.TestCase):
 
     def setUp(self):
-
+        super(OvercloudRoleShellTest, self).setUp()
         self.outfile = six.StringIO()
         self.tuskar = mock.MagicMock()
         self.shell = overcloud_roles_shell
-        super(RacksShellTest, self).setUp()
 
     @mock.patch('tuskarclient.common.utils.find_resource')
     @mock.patch('tuskarclient.v1.overcloud_roles_shell.print_role_detail')
     def test_overcloud_role_show(self, mock_print_detail, mock_find_resource):
         mock_find_resource.return_value = mock_overcloud()
         args = empty_args()
-        args.id = '5'
+        args.role = '5'
 
         self.shell.do_overcloud_role_show(self.tuskar, args,
                                           outfile=self.outfile)
@@ -94,7 +93,7 @@ class RacksShellTest(tutils.TestCase):
     def test_overcloud_role_update(self, mock_print, mock_find_resource):
         mock_find_resource.return_value = mock_overcloud()
         args = empty_args()
-        args.id = '5'
+        args.role = '5'
         args.name = 'My Overcloud Role'
         args.description = 'This is an Overcloud Role.'
         args.image_name = 'image'
@@ -118,7 +117,7 @@ class RacksShellTest(tutils.TestCase):
     def test_overcloud_role_delete(self, mock_find_resource):
         mock_find_resource.return_value = mock_overcloud()
         args = empty_args()
-        args.id = '5'
+        args.role = '5'
 
         self.shell.do_overcloud_role_delete(self.tuskar, args,
                                             outfile=self.outfile)
